//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[Shousushi](-shousushi.md)

# Shousushi

[common]\
val [Shousushi](-shousushi.md): [Yaku](../-yaku/index.md)

小四喜
